Stan Math Library: stan/math/rev/arr/fun/decouple_ode_states.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
decouple_ode_states.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/prim/scal/meta/return_type.hpp>`
`#include <stan/math/rev/scal/meta/is_var.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T_initial , typename T_param >
std::vector< std::vector< typename stan::return_type< T_initial, T_param >::type > > | stan::math::decouple_ode_states (const std::vector< std::vector< double > > &y, const std::vector< T_initial > &y0, const std::vector< T_param > &theta)
| Takes sensitivity output from integrators and returns results in precomputed_gradients format. More...
template<>
std::vector< std::vector< double > > | stan::math::decouple_ode_states (const std::vector< std::vector< double > > &y, const std::vector< double > &y0, const std::vector< double > &theta)
| The decouple ODE states operation for the case of no sensitivities is equal to the indentity operation. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.